aboutsummaryrefslogtreecommitdiff
path: root/.ci/scripts/linux/upload.sh
diff options
context:
space:
mode:
authorLC <mathew1800@gmail.com>2021-01-14 18:46:27 -0500
committerGitHub <noreply@github.com>2021-01-14 18:46:27 -0500
commit93f7719eed11309f0e312ce330095307ac40ca8e (patch)
tree2164e4acd2474b2a2741257b5cb4458adc3f74a5 /.ci/scripts/linux/upload.sh
parent4038ca2e5d247d37f781923e2fff6a41b5d92ae2 (diff)
parent0d24b1a31b662146dca4444c7e22e0dddbc1f6bd (diff)
Merge pull request #5302 from lat9nq/appimage-update
ci/linux: Make Mainline AppImages updateable
Diffstat (limited to '.ci/scripts/linux/upload.sh')
-rw-r--r--.ci/scripts/linux/upload.sh24
1 files changed, 20 insertions, 4 deletions
diff --git a/.ci/scripts/linux/upload.sh b/.ci/scripts/linux/upload.sh
index 7175e4cb5..b2ea07388 100644
--- a/.ci/scripts/linux/upload.sh
+++ b/.ci/scripts/linux/upload.sh
@@ -2,8 +2,7 @@
. .ci/scripts/common/pre-upload.sh
-APPIMAGE_NAME="yuzu-x86_64.AppImage"
-NEW_APPIMAGE_NAME="yuzu-${GITDATE}-${GITREV}-x86_64.AppImage"
+APPIMAGE_NAME="yuzu-${GITDATE}-${GITREV}.AppImage"
REV_NAME="yuzu-linux-${GITDATE}-${GITREV}"
ARCHIVE_NAME="${REV_NAME}.tar.xz"
COMPRESSION_FLAGS="-cJvf"
@@ -19,7 +18,24 @@ mkdir "$DIR_NAME"
cp build/bin/yuzu-cmd "$DIR_NAME"
cp build/bin/yuzu "$DIR_NAME"
-# Copy the AppImage to the artifacts directory and avoid compressing it
-cp "build/${APPIMAGE_NAME}" "${ARTIFACTS_DIR}/${NEW_APPIMAGE_NAME}"
+# Build an AppImage
+cd build
+
+wget -nc https://github.com/AppImage/AppImageKit/releases/download/continuous/appimagetool-x86_64.AppImage
+chmod 755 appimagetool-x86_64.AppImage
+
+if [ "${RELEASE_NAME}" = "mainline" ]; then
+ # Generate update information if releasing to mainline
+ ./appimagetool-x86_64.AppImage -u "gh-releases-zsync|yuzu-emu|yuzu-${RELEASE_NAME}|latest|yuzu-*.AppImage.zsync" AppDir "${APPIMAGE_NAME}"
+else
+ ./appimagetool-x86_64.AppImage AppDir "${APPIMAGE_NAME}"
+fi
+cd ..
+
+# Copy the AppImage and update info to the artifacts directory and avoid compressing it
+cp "build/${APPIMAGE_NAME}" "${ARTIFACTS_DIR}/"
+if [ -f "build/${APPIMAGE_NAME}.zsync" ]; then
+ cp "build/${APPIMAGE_NAME}.zsync" "${ARTIFACTS_DIR}/"
+fi
. .ci/scripts/common/post-upload.sh